@@ -5,6 +5,7 @@ use dyn_clone::DynClone;
 
 use crate::{DefaultModifiers, Renderable};
 use crate::components::{Alignment, Appendable, HStack, Icon, Text, TextStyle};
+use crate::components::badge::{Badge, BadgeSupport, BadgeModifiers};
 use crate::node::{Node, NodeContainer};
 
 #[derive(Debug, Clone)]
@@ -12,6 +13,7 @@ pub struct Tag {
     node: Node,
     pub label: String,
     pub icon: Option<String>,
+    pub badge: Option<Badge>,
 }
 
 
@@ -21,6 +23,7 @@ impl Tag {
             node: Node::default(),
             label: label.to_string(),
             icon: None,
+            badge: None
         }
     }
 
@@ -33,6 +36,15 @@ impl Tag {
 
 impl DefaultModifiers<Tag> for Tag {}
 
+
+impl BadgeSupport for Tag {
+    fn add_badge(&mut self, badge: Badge) {
+        self.badge = Some(badge);
+    }
+}
+
+impl BadgeModifiers for Tag {}
+
 impl NodeContainer for Tag {
     fn get_node(&mut self) -> &mut Node {
         self.node.borrow_mut()
@@ -55,6 +67,10 @@ impl Renderable for Tag {
             Text::new(&self.label, TextStyle::Overline)
         }.render());
 
+        if let Some(badge) = tag.badge {
+            tag.node.children.push(badge.render());
+        }
+
         tag.node
     }
 }
\ No newline at end of file
